Learn R Programming

rxylib (version 0.2.6)

rxylib-package: Import XY-Data into R

Description

Provides access to the 'xylib' C++ library for to import xy data from powder diffraction, spectroscopy and other experimental methods, like gamma-ray spectrometry.

License: GPL-3 | LGPL-2.1 (for the C++ library 'xylib')

Arguments

Details

Funding

Between 2017-2019, the work of Sebastian Kreutzer as maintainer of the package was supported by LabEx LaScArBx (ANR - n. ANR-10-LABX-52).

Supported data formats: library version: 1.6.0

ID NAME DESCRIPTION FILE EXTENSION VALID_OPTIONS DATATYPE BLOCK_TYPE
[1,] cpi Sietronics Sieray CPI cpi ascii single
[2,] uxd Bruker Diffrac-AT UXD uxd ascii multiple
[3,] rigaku_dat Rigaku DAT dat ascii multiple
[4,] bruker_raw Siemens/Bruker RAW raw binary multiple
[5,] bruker_spc Bruker ESP300-E SPC spc binary single
[6,] vamas VAMAS ISO-14976 vms ascii multiple
[7,] philips_udf Philips UDF udf ascii single
[8,] spe PI WinSpec SPE spe binary multiple
[9,] pdcif Powder Diffraction CIF cif ascii multiple
[10,] philips_rd Philips PC-APD RD/SD rd sd binary single
[11,] xrdml PANalytical XRDML xrdml ascii multiple
[12,] canberra_mca Canberra MCA mca dat binary single
[13,] canberra_cnf Canberra CNF cnf binary single
[14,] xfit_xdd XFIT XDD xdd ascii single
[15,] riet7 RIET7/LHPM/PSI_DMC dat ascii single
[16,] dbws DBWS data dbw rit neu ascii single
[17,] chiplot ChiPLOT data chi ascii single
[18,] spectra Spectra / VGX 900 1 2 3 4 5 6 7 8 9 ascii multiple
[19,] specsxy SPECS SpecsLab2 xy xy ascii multiple
[20,] csv CSV or TSV csv tsv tab decimal-comma ascii single
[21,] xsyg Freiberg Instruments (FI) Lexsyg xsyg ascii multiple